#
# spec file for package Fragments
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _lto_cflags %{?_lto_cflags} -ffat-lto-objects

Name:           Fragments
Version:        2.1.1
Release:        1.3
Summary:        A GTK4 BitTorrent Client
License:        GPL-3.0-only
Group:          Productivity/Networking/Other
URL:            https://gitlab.gnome.org/World/Fragments
Source:         %{name}-%{version}.tar.xz
Source2:        vendor.tar.zst
Source3:        cargo_config

BuildRequires:  appstream-glib
BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  cargo-packaging >= 1.2.0+3
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  git
BuildRequires:  libxml2-tools
BuildRequires:  meson
BuildRequires:  openssl-devel >= 0.9.7
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gio-2.0) >= 2.66
BuildRequires:  pkgconfig(glib-2.0) >= 2.66
BuildRequires:  pkgconfig(gtk4) >= 4.0.0
BuildRequires:  pkgconfig(libadwaita-1) >= 1.2.0
BuildRequires:  pkgconfig(sqlite3) >= 3.20
Requires:       transmission-daemon

%description
Fragments is an easy to use BitTorrent client which follows the
GNOME HIG and includes well thought-out features.

%lang_package

%prep
%autosetup -p1 -a2
mkdir .cargo
cp %{SOURCE3} .cargo/config

%build
export RUSTFLAGS="%{build_rustflags}"
%meson
%meson_build

%install
export RUSTFLAGS="%{build_rustflags}"
%meson_install
%find_lang fragments %{?no_lang_C}

%check
export RUSTFLAGS="%{build_rustflags}"
%meson_test
%cargo_test

%files
%license COPYING.md
%doc README.md
%{_bindir}/fragments
%{_datadir}/applications/de.haeckerfelix.Fragments.desktop
%{_datadir}/glib-2.0/schemas/de.haeckerfelix.Fragments.gschema.xml
%{_datadir}/icons/hicolor/
%{_datadir}/metainfo/de.haeckerfelix.Fragments.metainfo.xml
%{_datadir}/dbus-1/services/de.haeckerfelix.Fragments.service
%{_datadir}/fragments/

%files lang -f fragments.lang

%changelog
* Fri Jun 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.1.1:
  + New F10 shortcut to open main menu.
  + Updated translations.
* Wed Jun 21 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Use %%build_rustflags instead of the deprecated
  %%__default_rustflags macro. Requires at least cargo-packaging
  %%1.2.0+3.
* Thu Jun 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Use %%__default_rustflags instead of the deprecated %%__rustflags
  macro. Requires at least cargo-packaging 1.2.0+2.
* Wed Apr 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Use rustflags in check section also + run cargo_test macro.
- Add constraints, we need a bigger hdd than some of the builders
  provide.
* Wed Apr 12 2023 Luciano Santos <luc14n0@opensuse.org>
- Drop %%rustflags macro definition and use %%__rustflags from
  cargo-packaging package instead.
* Thu Mar 16 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Automatic update of vendored dependencies
* Wed Dec 28 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.1:
  + Allow changing the location of a single torrent
  + New menu option to resume all torrents
  + Torrent errors are now displayed instead of ignoring them
    silently
  + Display message when the configured download/incomplete
    directory is not available
  + Transmission daemon is only started when necessary, and no
    longer runs continuously in the background
  + Application window can now be closed with CTRL+W
  + Fixed issue that already added magnet links were not recognised
  + Fixed a crash related to the "Automatically Start Torrents"
    setting
  + User interface improvements by using new Libadwaita widgets.
  + Updated translations.
- Replace rust-packaging with cargo-packaging BuildRequires.
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Thu Feb 17 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.0.2 (boo#1195875):
  + Port to rust.
  + Port to gtk4
  + Switch to rely on transmission-daemon as torrent backend.
- Drop BuildRequires no longer needed:
  + libcurl-devel
  + libevent-devel
  + libminiupnpc-devel
  + vala
  + pkgconfig(gio-unix-2.0)
  + pkgconfig(gobject-2.0)
  + pkgconfig(gtk+-3.0)
  + pkgconfig(libhandy-0.0)
  + pkgconfig(zlib)
- Add new BuildRequires:
  + git
  + libxml2-tools
  + rust-packaging
  + pkgconfig(dbus-1)
  + pkgconfig(gtk4)
  + pkgconfig(libadwaita-1)
  + pkgconfig(sqlite3)
- Drop patches fixed upstream:
  + Fragments-fix-vala-syntax-error.patch
  + Fragments-no-duplicate-LINGUAS.patch
  + Fragments-fix-meson-0610.patch
- Add transmission-daemon Requires.
- Add rust config bits in service.
- Add _lto_cflags %%%%{?_lto_cflags} -ffat-lto-objects define, build
  fails linking without.
* Tue Feb  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add Fragments-fix-meson-0610.patch: Fix build with meson 0.61.0
  and newer.
- Drop update-desktop-files BuildRequires and macro, no longer
  needed.
- Add appstream-glib and desktop-file-utils BuildRequires and add
  check section and run meson_test macro, validate appadata and
  desktop file.
- Replace gcc-c++ with generic c++_compiler and c_compiler
  BuildRequires.
* Thu Jan 20 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add Fragments-no-duplicate-LINGUAS.patch: LINGUAS: Order
  alphabetically, remove duplicated entry, backported commit
  a2fdc6f7.
* Fri Nov 13 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add Fragments-fix-vala-syntax-error.patch: Fix vala syntax error
  during build.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Mar 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.4:
  + New application icon + theme.
  + New 'Open' button to open downloaded torrents faster.
  + Several bug fixes.
  + Updated translations.
* Tue Dec 25 2018 bjorn.lie@gmail.com
- Initial packaging for openSUSE, version 1.3.
